@@ -101,11 +101,12 @@ class PSD:
         print("Check validity for command " + command)
 
         if "cmdError" not in command and self.isCommandValid(command):
-            if "g" in command or "G" in command:
-                result = self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter)
+            #if "g" in command or "G" in command:
+            result = self.checkGgPairs(self.command.command_g_counter, self.command.command_G_counter)
+            if result:
                 print("Valid command!")
-        else:
-            print("Error! Wrong parameter value for command! Check manual!")
+            else:
+                print("Error! Wrong parameter value for command! Check manual!")
 
         return result
 
